@@ -15,7 +15,7 @@ echo "   --------------- Installation of Ding ---------------"
 echo "A Dictionary lookup program and a German-English Dictionary"
 echo ""
 
-NEEDPROG="wish"
+NEEDPROG="wish aaaaa"
 
 for f in $NEEDPROG; do
  
